/**
 * @file          /kiran-ssr-manager/home/tangjie02/git/kylin-license/include/license_i.h
 * @brief         
 * @author        tangjie02 <tangjie02@kylinos.com.cn>
 * @copyright (c) 2020 KylinSec. All rights reserved. 
 */

#pragma once

#ifndef LICENSE_NEW_INTERFACE
#warning This file will be deprecated. please use license-i.h file
#endif

enum LicenseActivationStatus
{
    // 未激活
    LAS_UNACTIVATED = 0,
    // 已激活
    LAS_ACTIVATED,
    LAS_LAST,
};

enum LicenseServiceStatus
{
    // 非法，如果当前时间比安装时间小很多说明用户手动修改了时间，可以当作已过期处理，如果条件允许，需要向用户报告该错误
    LICENSE_SERVICE_STATUS_INVALID = 0,
    // 已过期，当前时间大于过期时间
    LICENSE_SERVICE_STATUS_EXPIRED,
    // 未过期
    LICENSE_SERVICE_STATUS_UNEXPIRED,
    LICENSE_SERVICE_STATUS_LAST,
};

enum LicenseActivationType
{
    // 未知
    LICENSE_ACTIVATION_TYPE_UNKNOWN = 0,
    // 手动激活
    LICENSE_ACTIVATION_TYPE_MANNUAL,
    // 离线批量激活
    LICENSE_ACTIVATION_TYPE_OFFLINE,
    // 在线激活
    LICENSE_ACTIVATION_TYPE_ONLINE,
};

enum LicenseInstallType
{
    // 下面是老的安装形态类型，以后生成的授权码不再使用
    // 桌面应用终端
    LICENSE_INSTALL_TYPE_OLD_DESKTOP = 1,
    // 服务器运行版本
    LICENSE_INSTALL_TYPE_OLD_SERVER,
    // 工作站运行版本
    LICENSE_INSTALL_TYPE_OLD_WORKSTATION,
    // 工控版本
    LICENSE_INSTALL_TYPE_OLD_INDUSTRIAL,
    //
    LICENSE_INSTALL_TYPE_OLD_LAST = 10,

    // 下面是新的安装形态类型
    // 未知，如果是未知形态，不应该发放授权码
    LICENSE_INSTALL_TYPE_UNKNOWN = 11,
    // 桌面版
    LICENSE_INSTALL_TYPE_DESKTOP,
    // 服务器版
    LICENSE_INSTALL_TYPE_SERVER,
    // 工控版
    LICENSE_INSTALL_TYPE_INDUSTRIAL,
    // 开发版
    LICENSE_INSTALL_TYPE_DEVELOPMENT,
    LICENSE_INSTALL_TYPE_LAST,
};

enum LicenseErrorCode
{
    LEC_SUCCESS = 0,

    /* ------------ common ------------- */
    LEC_COMMON_NULL_POINTER,
    LEC_COMMON_UNSUPPORTED_OPERATION,
    LEC_COMMON_IO_ERROR,

    /* ------------ license ------------- */
    // 授权码长度错误
    LEC_LICENSE_LENGTH_INVALID = 1000,
    // 字符串形式的授权码无法转换为2进制表示的授权码
    LEC_LICENSE_TRANS_FAILED,
    // 无法解密16字节的授权码
    LEC_LICENSE_DECODE_FAILED,
    // 解密成功，但是解密后的日期部分不是一个合法的日期格式
    LEC_LICENSE_DATE_INVALID,
    // 机器码和授权码不匹配
    LEC_UNMATCH_MACHINE_CODE,
    // 机器码匹配，但是机器码中的安装形态是桌面版的，而当前机器是服务器
    LEC_INSTALL_TYPE_UNMATCH_MACHINE,
    // 授权码已过期
    LEC_LICENSE_EXPIRED,
    // 字符串形式的机器码无法转换为2进制表示的机器码
    LEC_MACHINE_CODE_TRANS_FAILED,
    // 授权码同步到文件(/etc/.license)失败
    LEC_SYNC_TO_FILE_FAILED,
    // 过期时间超过2256年
    LEC_EXPIRED_DATE_LARGE,
    //机器码与安装形态不匹配
    MACHINE_CODE_UNMATCH_INSTALL_TYPE,

    /* ------------ ukey ------------- */
    // UkeyGroup未初始化
    LEC_UKEY_GROUP_UNINIT = 2000,
    // 没有找到UKey设备
    LEC_UKEY_NOT_FOUND,
    // 存在UKey设备但已经没有点数或者已经过期
    LEC_UKEY_NOT_USABLE_UKEY_DEVICE,
    // UKey设备记录的过期时间不是合法格式
    LEC_UKEY_EXPIRED_DATE_INVALIDE,
    // 根据机器码、过期时间、客户信息加密未授权码失败
    LEC_ENCODE_GENERATE_LICENSE_FAILED,
    // 生成的授权码二进制长度错误
    LEC_GENERATE_LICENSE_LENGTH_INALID,
    // 同步已授权信息到数据库失败
    LEC_SYNC_AUTH_TO_DB_FAILED,
    // 同步ukey高级存储区数据到数据库
    LEC_SYNC_UKEY_TO_DB_FAILED,
    // 非x86机器使用物理ukey设备
    LEC_UKEY_UNSUPPORTED_UNX86,
    // 调用c51程序生成授权码失败
    LEC_C51_GENERATE_LICENSE_FAILED,
    // 已授权机器超过最大内存
    LEC_UKEY_ITEM_EXCEED_LIMIT,
    // USBKey设备PIN验证失败
    LEC_UKEY_PIN_FAILED,
    // 写入机器码到USBKey设备失败
    LEC_UKEY_WRITE_MACHINE_CODE_FAILED,
    // 更新USBKey设备剩余点数
    LEC_UKEY_WRITE_REMAINING_POINTS_FAILED,
    // 机器码已经存在UKey中
    LEC_UKEY_ALREADY_EXIST_MACHINE_CODE,
    // 存在UKey设备但已经没有点数
    LEC_UKEY_NO_REMAINING_POINTS_2,
    // 机器码不存在UKey中
    LEC_UKEY_NOT_EXIST_MACHINE_CODE,
    // 不存在已使用点数
    LEC_UKEY_NO_USED_POINTS,

    /* ------------ online ------------- */
    // 连接服务器失败
    LEC_CONNECT_SERVER_FAILED = 3000,
    // 发送注册请求失败
    LEC_SEND_REQUEST_FAILED,
    // 等待服务器的响应数据超时
    LEC_SERVER_RESPONSE_TIMEOUT,
    // 服务器响应数据错误
    LEC_SERVER_RESPONSE_ERROR,

    /* ------------ generator ------------- */
    // 输入的日期不合法
    LEC_INPUT_DATE_INVALID,
    // 客户代码长度错误
    LEC_INPUT_CUSTOMER_LENGTH_INVALID,

    LEC_UNKNOWN = 10000,

};

/* ---------------------- DBUS -------------------- */
// deprecated macro definition
#define LICENSE_DBUS_NAME "com.kylinsec.Kiran.LicenseHelper"
#define LICENSE_DBUS_OBJECT_PATH "/com/kylinsec/Kiran/LicenseHelper"

#define LICENSE_HELPER_DBUS_NAME "com.kylinsec.Kiran.LicenseHelper"
#define LICENSE_HELPER_OBJECT_PATH "/com/kylinsec/Kiran/LicenseHelper"
#define LICENSE_MANAGER_DBUS_NAME "com.kylinsec.Kiran.LicenseManager"
#define LICENSE_MANAGER_OBJECT_PATH "/com/kylinsec/Kiran/LicenseManager"
#define LICENSE_OBJECT_OBJECT_PATH "/com/kylinsec/Kiran/LicenseObject"

#define LICENSE_DBUS_TIMEOUT_MSEC 3000

//
#define LICENSE_JK_ACTIVATION_STATUS "activation_status"
#define LICENSE_JK_SERVICE_STATUS "service_status"
#define LICENSE_JK_MACHINE_CODE "machine_code"
#define LICENSE_JK_EXPIRED_TIME "expired_time"
#define LICENSE_JK_FIRST_BOOT_TIME "first_boot_time"
#define LICENSE_JK_INSTALL_TYPE "install_type"
#define LICENSE_JK_IS_PG "is_pg"
#define LICENSE_JK_ACTIVATION_CODE "activation_code"
#define LICENSE_JK_ACTIVATION_TYPE "activation_type"
#define LICENSE_JK_ACTIVATION_TIME "activation_time"
#define LICENSE_JK_CUSTOMER_INFO "customer_info"

// 废弃，请使用LicenseActivationStatus
enum LicenseStatus
{
    // 未注册
    LICENSE_STATUS_UNREGISTERD = 0,
    // 已注册
    LICENSE_STATUS_REGISTERD,
    LICENSE_STATUS_LAST,
};

// 废弃，请使用LicenseActivationType
enum LicenseRegisterType
{
    // 未知
    LICENSE_REGISTER_TYPE_UNKNOWN = 0,
    // 手动注册
    LICENSE_REGISTER_TYPE_MANNUAL,
    // 离线批量注册
    LICENSE_REGISTER_TYPE_OFFLINE,
    // 在线注册
    LICENSE_REGISTER_TYPE_ONLINE,
};